@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -44,10 +45,13 @@ class Engine {
 		
 		int extremeAvailable;
 
-		char keyState[350];
+		char keyState[SDL_NUM_SCANCODES];
 		char mouseLeft, mouseRight;
 		
 		int joyX, joyY;
+		int joyprevX, joyprevY;
+		int joykeyX, joykeyY;
+		bool joykeyFire;
 		int joystickState[32]; // hopefully no one has a joystick with this many buttons(!)
 		bool waitForButton;
 		bool waitForKey;
@@ -100,7 +104,7 @@ class Engine {
 	int getMouseX() const;
 	int getMouseY() const;
 
-	void setMouse(int x, int y);
+	void moveMouse(int dx, int dy);
 	bool userAccepts();
 	
 	void clearCheatVars();
