@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -29,16 +30,6 @@ Game::Game()
 
 	gore = 1;
 	skill = 1;
-#ifdef SDL_FRAMEWORK
-	float r,g,b;
-	if (SDL_GetGamma(&r, &g, &b) != -1) {
-		if (r != g || g != b) {
-			brightness = -1;
-		} else {
-			brightness = 10 * r;
-		}
-	}
-#endif
 
 	clear();
 }
