@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,6 +19,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+void SDL_SetAlpha(SDL_Surface *surface, uint8_t value);
+
 class Graphics {
 
 	private:
@@ -57,6 +60,9 @@ class Graphics {
 
 		bool takeRandomScreenShots;
 
+		SDL_Window *window;
+		SDL_Renderer *renderer;
+		SDL_Texture *texture;
 		SDL_Surface *screen, *background;
 		SDL_Surface *tile[MAX_TILES];
 		
