@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,12 +21,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
-Joystick::Joystick()
+Joystick::Joystick():
+	sensitivity(25000)
 {
-	sensitivity = 25000;
+	static int defaultValue[CONTROL::MAX] = {-2, -2, -2, -2, 1, 0, 3, 7, 6};
 
-	for (int i = 0 ; i < CONTROL::MAX ; i++)
-	{
-		control[i] = i;
-	}
+	for (int i = 0; i < CONTROL::MAX; i++)
+		control[i] = defaultValue[i];
 }
