@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,7 +34,7 @@ bool PersistData::setData(const char *data)
 {
 	if (strlen(data) > 149)
 	{
-		debug(("ERROR: PERSISTANT DATA LINE EXCEEDS 150 CHARACTERS! IS %zd!\n", strlen(data)));
+		debug(("ERROR: PERSISTANT DATA LINE EXCEEDS 150 CHARACTERS! IS %lu!\n", (unsigned long)strlen(data)));
 		return false;
 	}
 	
