@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -49,6 +50,3 @@ extern Map map;
 
 extern Entity player;
 extern Entity defItem[MAX_ITEMS];
-
-// this is used exclusively by the bosses
-Boss *self;
