@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -251,6 +252,7 @@ const char skill[][10] = {
 
 #define PAR_WEIGHTLESS	1
 #define PAR_COLLIDES	2
+#define PAR_LIQUID      4
 
 /* ######### effect flags ########### */
 
@@ -376,6 +378,12 @@ enum {
 	PAK_TAGS
 };
 
+/* ######### miscellaneous ############## */
+
+#define DIR_X 1
+#define DIR_Y 2
+#define DIR_XY 3
+
 /* ############# debug ################## */
 
 #if DEBUG
