@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -129,7 +130,7 @@ void droidBossChangeFrequency()
 			break;
 	}
 	
-	audio.playSound(SND_BOSSCUSTOM1, CH_AMBIANCE);
+	audio.playSound(SND_BOSSCUSTOM1, CH_AMBIANCE, self->x);
 }
 
 void droidBossDie()
@@ -182,7 +183,7 @@ void droidBossReact()
 	if ((Math::prand() % 10) == 0)
 	{
 		Math::addBit(&self->flags, ENT_IMMUNE);
-		audio.playSound(SND_BOSSCUSTOM2, CH_SPAWN);
+		audio.playSound(SND_BOSSCUSTOM2, CH_SPAWN, self->x);
 		self->custom = 5;
 		self->think = &droidGoCrazy;
 		self->setActionFinished(2);
