@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -130,7 +131,7 @@ void galdovReact()
 
 void galdovSplit(int i)
 {
-	audio.playSound(SND_BOSSCUSTOM1, CH_AMBIANCE);
+	audio.playSound(SND_BOSSCUSTOM1, CH_AMBIANCE, map.boss[0]->x);
 	
 	map.boss[i]->active = true;
 	map.boss[i]->health = 4 * game.skill;
@@ -388,7 +389,7 @@ void galdovDie()
 	if (map.mainBossPart != NULL)
 	{
 		map.mainBossPart = NULL;
-		audio.playSound(SND_BOSSCUSTOM2, CH_AMBIANCE);
+		audio.playSound(SND_BOSSCUSTOM2, CH_AMBIANCE, self->x);
 	}
 	
 	if ((self->health % 5) == 0)
@@ -474,8 +475,8 @@ void galdovInit()
 	
 	Math::addBit(&map.boss[0]->flags, ENT_AIMS);
 	
-	SDL_SetAlpha(graphics.getSprite("GaldovInvsLeft", true)->image[0], SDL_SRCALPHA|SDL_RLEACCEL, 100);
-	SDL_SetAlpha(graphics.getSprite("GaldovInvsRight", true)->image[0], SDL_SRCALPHA|SDL_RLEACCEL, 100);
+	SDL_SetAlpha(graphics.getSprite("GaldovInvsLeft", true)->image[0], 100);
+	SDL_SetAlpha(graphics.getSprite("GaldovInvsRight", true)->image[0], 100);
 	
 	for (int i = 1 ; i < 10 ; i++)
 	{
