@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,6 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include <errno.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
@@ -30,20 +32,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <SDL_image/SDL_image.h>
 #include <SDL_mixer/SDL_mixer.h>
 #include <SDL_ttf/SDL_ttf.h>
+#include <SDL_net/SDL_net.h>
 #include <CoreFoundation/CoreFoundation.h>
 extern C_LINKAGE void openHelpURL();
 #ifndef SDL_GetGamma
 extern DECLSPEC int SDLCALL SDL_GetGamma(float *red, float *green, float *blue);
 #endif
 #else
-#include "SDL/SDL.h"
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_mixer.h"
-#include "SDL/SDL_ttf.h"
-#include "SDL/SDL_net.h"
+#include "SDL2/SDL.h"
+#include "SDL2/SDL_image.h"
+#include "SDL2/SDL_mixer.h"
+#include "SDL2/SDL_ttf.h"
+#include "SDL2/SDL_net.h"
 #endif
 
-#ifndef WIN32
+#if !defined(_WIN32) && !defined(__APPLE__)
 #include <libintl.h>
 #define _(string) gettext(string)
 #else
@@ -53,9 +56,9 @@ extern DECLSPEC int SDLCALL SDL_GetGamma(float *red, float *green, float *blue);
 #define textdomain(x) while(false)
 #endif
 
-#if !defined(OpenBSD) && !defined(FreeBSD)
-#define strlcat(dest, src, n) strncat((dest), (src), (n) - 1)
-#define strlcpy(dest, src, n) do {strncpy((dest), (src), (n)); (dest)[(n) - 1] = 0;} while(false)
+#if !defined(OpenBSD) && !defined(FreeBSD) && !defined(__APPLE__)
+static inline void strlcat(char *dest, const char *src, size_t n) { strncat(dest, src, n - 1); }
+static inline void strlcpy(char *dest, const char *src, size_t n) { strncpy(dest, src, n); dest[n - 1] = 0; }
 #endif
 
 #include "defs.h"
