@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -598,9 +599,6 @@ int doHub()
 	Uint32 frameLimit = SDL_GetTicks() + 16;
 	Uint32 now = SDL_GetTicks();
 	
-	int mouseXDelta = 0;
-	int mouseYDelta = 0;
-
 	while (rtn == -1)
 	{
 		graphics.updateScreen();
@@ -626,31 +624,32 @@ int doHub()
 		engine.getInput();
 		config.populate();
 		
+		int mouseXDelta = 0;
+		int mouseYDelta = 0;
+
 		if (config.isControl(CONTROL::RIGHT))
 		{
-			mouseXDelta = 5;
+			mouseXDelta += 5;
 		}
 		
 		if (config.isControl(CONTROL::LEFT))
 		{
-			mouseXDelta = -5;
+			mouseXDelta -= 5;
 		}
 		
 		if (config.isControl(CONTROL::DOWN))
 		{
-			mouseYDelta = 5;
+			mouseYDelta += 5;
 		}
 		
 		if (config.isControl(CONTROL::UP) || config.isControl(CONTROL::JUMP))
 		{
-			mouseYDelta = -5;
+			mouseYDelta -= 5;
 		}
 
 		if ((mouseXDelta != 0) || (mouseYDelta != 0))
 		{
-			engine.setMouse(engine.getMouseX() + (int)mouseXDelta, engine.getMouseY() + (int)mouseYDelta);
-			mouseXDelta = 0;
-			mouseYDelta = 0;
+			engine.moveMouse(mouseXDelta, mouseYDelta);
 		}
 
 		hubPoint = (HubLevel*)hubList.getHead();
@@ -742,7 +741,7 @@ int doHub()
 		// Collisions for Panel Buttons
 		if ((showMIAs) || (showStats))
 		{
-		    // SDLK_LCTRL is the "fire" button.
+		    // SDL_SCANCODE_LCTRL is the "fire" button.
 			if (engine.mouseLeft || config.isControl(CONTROL::FIRE))
 			{
 				if (Collision::collision(engine.getMouseX(), engine.getMouseY(), 1, 1, 270, 310, 32, 32))
