@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,6 +21,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
+extern void initConfig();
 extern void initSystem();
 extern void cleanup();
 
@@ -45,18 +47,3 @@ extern void checkStartCutscene();
 extern void easyGameFinished();
 
 extern void presentPlayerMedal(const char *tname);
-
-Audio audio;
-Config config;
-Engine engine;
-Game game;
-GameData gameData;
-Graphics graphics;
-Map map;
-ReplayData replayData;
-MedalServer medalServer;
-
-Entity defEnemy[MAX_ENEMIES];
-Entity defItem[MAX_ITEMS];
-Entity player;
-Weapon weapon[MAX_WEAPONS];
