@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -284,7 +285,7 @@ void getMapTokens()
 						
 					debug(("Setting Alpha for Tile %d\n", param[0]));
 
-					SDL_SetAlpha(graphics.tile[param[0]], SDL_SRCALPHA|SDL_RLEACCEL, 130);
+					SDL_SetAlpha(graphics.tile[param[0]], 130);
 
 					while (true)
 					{
