@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,6 +21,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "mapEditor.h"
 
+String *stringHead = new String;
+String *stringTail = stringHead;
+
+Audio audio;
+Engine engine;
+Game game;
+GameData gameData;
+Graphics graphics;
+Map map;
+
+Entity defEnemy[MAX_ENEMIES];
+Entity defItem[MAX_ITEMS];
+Entity player;
+Weapon weapon[MAX_WEAPONS];
+
 MedalServer medalServer;
 Config config;
 ReplayData replayData;
@@ -61,7 +77,7 @@ void showMap(int *mapX, int *mapY)
 {
 	SDL_FillRect(graphics.screen, NULL, graphics.black);
 
-	engine.keyState[SDLK_SPACE] = 0;
+	engine.keyState[SDL_SCANCODE_SPACE] = 0;
 	int moveTimer = 0;
 
 	while (true)
@@ -70,7 +86,7 @@ void showMap(int *mapX, int *mapY)
 		engine.getInput();
 		config.populate();
 
-		if (engine.keyState[SDLK_SPACE])
+		if (engine.keyState[SDL_SCANCODE_SPACE])
 			break;
 			
 		for (int x = 0 ; x < MAPWIDTH ; x++)
@@ -100,16 +116,16 @@ void showMap(int *mapX, int *mapY)
 
 		if (moveTimer == 0)
 		{
-			if (engine.keyState[SDLK_LEFT])
+			if (engine.keyState[SDL_SCANCODE_LEFT])
 				*mapX -= 1;
 
-			if (engine.keyState[SDLK_RIGHT])
+			if (engine.keyState[SDL_SCANCODE_RIGHT])
 				*mapX += 1;
 
-			if (engine.keyState[SDLK_UP])
+			if (engine.keyState[SDL_SCANCODE_UP])
 				*mapY -= 1;
 
-			if (engine.keyState[SDLK_DOWN])
+			if (engine.keyState[SDL_SCANCODE_DOWN])
 				*mapY += 1;
 		}
 
@@ -124,7 +140,7 @@ void showMap(int *mapX, int *mapY)
 		SDL_Delay(16);
 	}
 
-	engine.keyState[SDLK_SPACE] = 0;
+	engine.keyState[SDL_SCANCODE_SPACE] = 0;
 }
 
 int nextBlock(int current, int dir)
@@ -364,7 +380,7 @@ void addTileDecoration()
 		}
 	}
 	
-	engine.keyState[SDLK_F1] = 0;
+	engine.keyState[SDL_SCANCODE_F1] = 0;
 }
 
 void fillHorizontal(int block, int x, int y)
@@ -551,26 +567,26 @@ int main(int argc, char *argv[])
 
 		if (allowMove == 0)
 		{
-			if (engine.keyState[SDLK_UP]) {mapY--; allowMove = MOVESPEED;}
-			if (engine.keyState[SDLK_DOWN]) {mapY++; allowMove = MOVESPEED;}
-			if (engine.keyState[SDLK_LEFT]) {mapX--; allowMove = MOVESPEED;}
-			if (engine.keyState[SDLK_RIGHT]) {mapX++; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_UP]) {mapY--; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_DOWN]) {mapY++; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_LEFT]) {mapX--; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_RIGHT]) {mapX++; allowMove = MOVESPEED;}
 
-			if (engine.keyState[SDLK_PAGEDOWN]) {mapY += 10; allowMove = MOVESPEED;}
-			if (engine.keyState[SDLK_PAGEUP]) {mapY -= 10; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_PAGEDOWN]) {mapY += 10; allowMove = MOVESPEED;}
+			if (engine.keyState[SDL_SCANCODE_PAGEUP]) {mapY -= 10; allowMove = MOVESPEED;}
 
-			if (engine.keyState[SDLK_1]) editing = 0;
-			if (engine.keyState[SDLK_2]) editing = 1;
-			if (engine.keyState[SDLK_3]) editing = 2;
+			if (engine.keyState[SDL_SCANCODE_1]) editing = 0;
+			if (engine.keyState[SDL_SCANCODE_2]) editing = 1;
+			if (engine.keyState[SDL_SCANCODE_3]) editing = 2;
 			
-			if (engine.keyState[SDLK_0]) fillHorizontal(currentBlock, mapX + x, mapY + y);
+			if (engine.keyState[SDL_SCANCODE_0]) fillHorizontal(currentBlock, mapX + x, mapY + y);
 
-			if (engine.keyState[SDLK_F1]) addTileDecoration();
+			if (engine.keyState[SDL_SCANCODE_F1]) addTileDecoration();
 
-			if (engine.keyState[SDLK_ESCAPE]) break;
+			if (engine.keyState[SDL_SCANCODE_ESCAPE]) break;
 		}
 
-		if (engine.keyState[SDLK_PERIOD])
+		if (engine.keyState[SDL_SCANCODE_PERIOD])
 		{
 			switch (editing)
 			{
@@ -585,10 +601,10 @@ int main(int argc, char *argv[])
 					break;
 			}
 
-			engine.keyState[SDLK_PERIOD] = 0;
+			engine.keyState[SDL_SCANCODE_PERIOD] = 0;
 		}
 
-		if (engine.keyState[SDLK_COMMA])
+		if (engine.keyState[SDL_SCANCODE_COMMA])
 		{
 			switch (editing)
 			{
@@ -603,7 +619,7 @@ int main(int argc, char *argv[])
 					break;
 			}
 
-			engine.keyState[SDLK_COMMA] = 0;
+			engine.keyState[SDL_SCANCODE_COMMA] = 0;
 		}
 
 		Math::limitInt(&currentMonster, 0, MAX_ENEMIES - 1);
@@ -615,9 +631,9 @@ int main(int argc, char *argv[])
 		if (defItem[currentItem].sprite[0] == NULL)
 			currentItem = 0;
 
-		if (engine.keyState[SDLK_SPACE]) {showMap(&mapX, &mapY);}
+		if (engine.keyState[SDL_SCANCODE_SPACE]) {showMap(&mapX, &mapY);}
 
-		if (engine.keyState[SDLK_s]) {saveMap(game.mapName); engine.keyState[SDLK_s] = 0;}
+		if (engine.keyState[SDL_SCANCODE_S]) {saveMap(game.mapName); engine.keyState[SDL_SCANCODE_S] = 0;}
 
 		if (mapX < 0) mapX = 0;
 		if (mapY < 0) mapY = 0;
