@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -115,7 +116,7 @@ void doMIAs()
 				{
 					Math::addBit(&mia->flags, ENT_WEIGHTLESS);
 					Math::addBit(&mia->flags, ENT_DYING);
-					audio.playSound(SND_TELEPORT1, CH_ANY);
+					audio.playSound(SND_TELEPORT1, CH_ANY, mia->x);
 				}
 			}
 			
