@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2004-2011 Parallel Realities
+Copyright (C) 2011-2015 Perpendicular Dimensions
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -130,7 +131,7 @@ void drawJoypadButtonOption(Widget *widget)
 	
 	// joysticks have a button 0 so we can't
 	// do the same thing as the keyboard(!)
-	if (*widget->value <= -1000)
+	if (*widget->value < -2)
 	{
 		snprintf(text, sizeof text, "...");
 	}
